# For the benefit of TestGlobalObject
class ImportableClass:
    pass
